﻿using System;
using System.IO;
using System.Threading.Tasks;
using Windows.Storage;
using Windows.UI.Popups;

namespace YourNamespace
{
    public class LittleWatson
    {
        const string filename = "LittleWatson.txt";

        internal static async Task ReportException(Exception ex, string extra)
        {
            try
            {
                var folder = ApplicationData.Current.LocalFolder;
                await SafeDeleteFile(folder);
                var file = await folder.CreateFileAsync(filename).AsTask();
                using (var output = new StreamWriter(await file.OpenStreamForWriteAsync()))
                {
                    output.WriteLine(extra);
                    output.WriteLine(ex.Message);
                    output.WriteLine(ex.StackTrace);
                    output.Flush();
                }

            }
            catch (Exception)
            {
            }
        }

        internal static async Task CheckForPreviousException()
        {
            var folder = ApplicationData.Current.LocalFolder;
            try
            {
                string contents = null;
                StorageFile file;
                try
                {
                    file = await folder.GetFileAsync(filename).AsTask();
                }
                catch
                {
                    file = null;
                }

                if (file == null)
                {
                    return;
                }

                using (var reader = new StreamReader(await file.OpenStreamForReadAsync()))
                {
                    contents = reader.ReadToEnd();
                }
                

                if (contents != null)
                {
                    var dialog = new MessageDialog("A problem occurred the last time you ran this application. Would you like to send an email to report it?","Problem Report");
                    dialog.Commands.Add(new UICommand("Send"){Id="send"});
                    dialog.Commands.Add(new UICommand("Ignore"){Id="ignore"});
                    var chosen = await dialog.ShowAsync();
                    if ((string)chosen.Id == "send")
                    {
#if(WINDOWS_PHONE_APP)
                        var email = new Windows.ApplicationModel.Email.EmailMessage();
                        email.To.Add(new Windows.ApplicationModel.Email.EmailRecipient("youremail@domain.com"));
                        email.Subject = "Your Subject Line";
                        email.Body = contents;
                        await Windows.ApplicationModel.Email.EmailManager.ShowComposeNewEmailAsync(email); 
#endif
                    }
                }
            }
            catch
            {
            }

            await SafeDeleteFile(folder);
        }

        private static async Task SafeDeleteFile(StorageFolder folder)
        {
            try
            {
                var file = await folder.GetFileAsync(filename).AsTask();
                await file.DeleteAsync(StorageDeleteOption.Default).AsTask();
            }
            catch
            {
            }
        }
    }
}
